skiptools.make_repeated_skips_from_time_signature
=================================================

.. autofunction:: abjad.tools.skiptools.make_repeated_skips_from_time_signature.make_repeated_skips_from_time_signature
